Changelog

Struct Changelog 

pub struct Changelog(/* private fields */);
Represents a changelog file.

This uses the keep a changelog format to parse and generate changelogs. There is very limited support for deviation from this format so the changelog should not yet be manually edited.

Implementations

Source

impl Changelog

pub fn new() -> Self

Constructs a new changelog.

pub fn title(&self) -> Option<Text<'_>>

Gets the changelog title.

pub fn description(&self) -> Option<MultilineText<'_>>

Gets the changelog description.

pub fn add_release(&mut self, release: impl Into<Release>) -> &mut Self

Adds a new release to the changelog.

pub fn with_release(self, release: impl Into<Release>) -> Self

Builds the changelog with the given release.

pub fn get_release(&self, version: impl AsRef<str>) -> Option<ReleaseRef<'_>>

Gets a release for the given version.

pub fn releases(&self) -> impl Iterator<Item = ReleaseRef<'_>>

Gets an iterator over the releases.

pub fn references(&self) -> impl Iterator<Item = ReferenceRef<'_>>

Gets an iterator over the references.