pub enum Manifest {
Cargo(CargoManifest),
}Expand description
The package manifest.
Variants
Cargo(CargoManifest)
A cargo package manifest.
Implementations
Sourceimpl Manifest
impl Manifest
pub fn try_as_cargo(self) -> Option<CargoManifest>
pub const fn try_as_cargo_ref(&self) -> Option<&CargoManifest>
pub fn try_as_cargo_mut(&mut self) -> Option<&mut CargoManifest>
Sourceimpl Manifest
impl Manifest
Sourcepub fn package_kind(&self) -> PackageKind
pub fn package_kind(&self) -> PackageKind
Gets the package kind.
Sourcepub fn from_bytes(kind: PackageKind, bytes: &[u8]) -> Result<Self, Error>
pub fn from_bytes(kind: PackageKind, bytes: &[u8]) -> Result<Self, Error>
Creates a manifest from the given bytes.
Sourceimpl Manifest
impl Manifest
Sourcepub fn get_dependency(&self, name: impl AsRef<str>) -> Option<DependencyRef<'_>>
pub fn get_dependency(&self, name: impl AsRef<str>) -> Option<DependencyRef<'_>>
Gets the dependency with the given name.
Sourcepub fn get_dependency_mut(
&mut self,
name: impl AsRef<str>,
) -> Option<DependencyMut<'_>>
pub fn get_dependency_mut( &mut self, name: impl AsRef<str>, ) -> Option<DependencyMut<'_>>
Gets the mutable dependency with the given name.
Sourcepub fn dependencies(&self) -> Dependencies<'_>
pub fn dependencies(&self) -> Dependencies<'_>
Gets the dependencies.
Sourcepub fn dependencies_mut(&mut self) -> DependenciesMut<'_>
pub fn dependencies_mut(&mut self) -> DependenciesMut<'_>
Gets the mutable dependencies.
Sourceimpl Manifest
impl Manifest
Sourcepub fn get_dev_dependency(
&self,
name: impl AsRef<str>,
) -> Option<DependencyRef<'_>>
pub fn get_dev_dependency( &self, name: impl AsRef<str>, ) -> Option<DependencyRef<'_>>
Gets the dev dependency with the given name.
Sourcepub fn get_dev_dependency_mut(
&mut self,
name: impl AsRef<str>,
) -> Option<DependencyMut<'_>>
pub fn get_dev_dependency_mut( &mut self, name: impl AsRef<str>, ) -> Option<DependencyMut<'_>>
Gets the mutable dev dependency with the given name.
Sourcepub fn dev_dependencies(&self) -> Dependencies<'_>
pub fn dev_dependencies(&self) -> Dependencies<'_>
Gets the dev dependencies.
Sourcepub fn dev_dependencies_mut(&mut self) -> DependenciesMut<'_>
pub fn dev_dependencies_mut(&mut self) -> DependenciesMut<'_>
Gets the mutable dev dependencies.
Sourceimpl Manifest
impl Manifest
Sourcepub fn get_build_dependency(
&self,
name: impl AsRef<str>,
) -> Option<DependencyRef<'_>>
pub fn get_build_dependency( &self, name: impl AsRef<str>, ) -> Option<DependencyRef<'_>>
Gets the build dependency with the given name.
Sourcepub fn get_build_dependency_mut(
&mut self,
name: impl AsRef<str>,
) -> Option<DependencyMut<'_>>
pub fn get_build_dependency_mut( &mut self, name: impl AsRef<str>, ) -> Option<DependencyMut<'_>>
Gets the mutable build dependency with the given name.
Sourcepub fn build_dependencies(&self) -> Dependencies<'_>
pub fn build_dependencies(&self) -> Dependencies<'_>
Gets the build dependencies.
Sourcepub fn build_dependencies_mut(&mut self) -> DependenciesMut<'_>
pub fn build_dependencies_mut(&mut self) -> DependenciesMut<'_>
Gets the mutable build dependencies.