pub struct Changelog(/* private fields */);Expand description
Represents a changelog file.
This uses the keep a changelog format to parse and generate changelogs. There is very limited support for deviation from this format so the changelog should not yet be manually edited.
Implementations
Sourceimpl Changelog
impl Changelog
Sourcepub fn description(&self) -> Option<MultilineText<'_>>
pub fn description(&self) -> Option<MultilineText<'_>>
Gets the changelog description.
Sourcepub fn add_release(&mut self, release: impl Into<Release>) -> &mut Self
pub fn add_release(&mut self, release: impl Into<Release>) -> &mut Self
Adds a new release to the changelog.
Sourcepub fn with_release(self, release: impl Into<Release>) -> Self
pub fn with_release(self, release: impl Into<Release>) -> Self
Builds the changelog with the given release.
Sourcepub fn get_release(&self, version: impl AsRef<str>) -> Option<ReleaseRef<'_>>
pub fn get_release(&self, version: impl AsRef<str>) -> Option<ReleaseRef<'_>>
Gets a release for the given version.
Sourcepub fn releases(&self) -> impl Iterator<Item = ReleaseRef<'_>>
pub fn releases(&self) -> impl Iterator<Item = ReleaseRef<'_>>
Gets an iterator over the releases.
Sourcepub fn references(&self) -> impl Iterator<Item = ReferenceRef<'_>>
pub fn references(&self) -> impl Iterator<Item = ReferenceRef<'_>>
Gets an iterator over the references.